@@ -27,6 +27,7 @@
 #include "sysprof-elf-symbol-resolver.h"
 #include "sysprof-flatpak.h"
 #include "sysprof-map-lookaside.h"
+#include "sysprof-podman.h"
 
 struct _SysprofElfSymbolResolver
 {
@@ -92,12 +93,20 @@ free_element_string (gpointer data)
 static void
 sysprof_elf_symbol_resolver_init (SysprofElfSymbolResolver *self)
 {
+  g_auto(GStrv) podman_dirs = NULL;
+
   self->debug_dirs = g_array_new (TRUE, FALSE, sizeof (gchar *));
   g_array_set_clear_func (self->debug_dirs, free_element_string);
+
   sysprof_elf_symbol_resolver_add_debug_dir (self, "/usr/lib/debug");
   sysprof_elf_symbol_resolver_add_debug_dir (self, "/usr/lib32/debug");
   sysprof_elf_symbol_resolver_add_debug_dir (self, "/usr/lib64/debug");
 
+  /* The user may have podman/toolbox containers */
+  podman_dirs = sysprof_podman_debug_dirs ();
+  for (guint i = 0; podman_dirs[i]; i++)
+    sysprof_elf_symbol_resolver_add_debug_dir (self, podman_dirs[i]);
+
   if (is_flatpak ())
     {
       g_auto(GStrv) debug_dirs = sysprof_flatpak_debug_dirs ();
@@ -391,6 +400,14 @@ sysprof_elf_symbol_resolver_resolve_with_context (SysprofSymbolResolver *resolve
   gchar *name = NULL;
   SysprofCaptureAddress begin, end;
 
+  /* If not user context, nothing we can do here */
+  if (context != SYSPROF_ADDRESS_CONTEXT_USER)
+    return NULL;
+
+  /* If this is a jitmap entry, bail early to save some cycles */
+  if ((address & SYSPROF_CAPTURE_JITMAP_MARK) == SYSPROF_CAPTURE_JITMAP_MARK)
+    return NULL;
+
   sysprof_elf_symbol_resolver_resolve_full (SYSPROF_ELF_SYMBOL_RESOLVER (resolver),
                                             time,
                                             pid,
